const system = require("../system");
const settings = require("../../config/settings");
const uuid = require('uuid');

class APIBase {
    constructor() {
        this.execClient = system.getObject("util.execClient");
        this.exTime = 6 * 3600;//缓存过期时间，6小时
    }
    //-----------------------新的模式------------------开始

    async doexecMethod(gname, methodname, pobj, query, req) {
        var param = {
            pobj: pobj,
            query: query
        }
        try {
            var result = await this[methodname](pobj, query, req);
            if (!result) {
                result = system.getResult(null, "请求的方法返回值为空");
            }
            result.requestId = result.requestId || uuid.v1();
            var tmpResult = pobj.actionType.indexOf("List") < 0 ? result : { status: result.status, message: result.message, requestId: result.requestId };
            this.execClient.execLogs("reqPath:" + req.path + "执行结果", param, "brg-user-apibase", tmpResult, null);
            return result;
        } catch (error) {
            var stackStr = error.stack ? error.stack : JSON.stringify(error);
            console.log(stackStr, "api调用出现异常，请联系管理员..........");
            var rtnerror = system.getResultFail(-200, "出现异常，error：" + stackStr);
            rtnerror.requestId = uuid.v1();
            this.execClient.execLogs("reqPath:" + req.path + "执行异常", param, "brg-user-apibase", null, stackStr);
            return rtnerror;
        }
    }

    //-----------------------新的模式------------------结束

    /**
     * 带超时时间的post请求
     * @param {*} params 请求数据-json格式
     * @param {*} url 请求地址
     * @param {*} ContentType 请求头类型，默认application/json
     * @param {*} headData 请求头内容-json格式，如：请求头中传递token,格式：{token:"9098902q849q0434q09439"}
     * @param {*} timeOut 超时时间
     */
    async execPostByTimeOut(params, url, ContentType, headData, timeOut = 60) {
        return await this.execClient.execPostTimeOutByBusiness("api.base", params, url, ContentType, headData, timeOut);
    }

}
module.exports = APIBase;
