const system = require("../../../system");
const Dao = require("../../dao.base");
class ServiceInfoDao extends Dao {
  constructor() {
    super(Dao.getModelName(ServiceInfoDao));
  }
  /**
   * 获取需求以及方案信息
   */
  async getNeedAndSolutionInfoByNeedNum(needNum) {
    var params = {
      need_num: needNum
    };
    var sql = "select * from v_need_needsolution where need_num = :need_num";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   *获取需求方案信息列表 
   */
  async getNeedSolutionList(ab) {
    var pageSize = ab.pageSize ? Number(ab.pageSize) : 10;
    var currentPage = ab.currentPage ? Number(ab.currentPage) : 1;
    var offset = (currentPage - 1) * pageSize;
    var params = {
      limit: pageSize,
      offset: offset
    };
    var sortType = "desc";
    if (ab.sortType == "asc") {
      sortType = "asc";
    }
    var returnRes = {
      pageSize: pageSize,//每页条数
      curPage: currentPage,//当前页数
      search: ab,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var dataCount = "select count(1) as dataCount from v_need_needsolution where 1=1 ";
    var sql = "select *,json_extract(solution_content,  '$.clerkName' ) as clerkName ,json_extract(solution_content,  '$.clerkPhone' ) as clerkPhone   from v_need_needsolution where 1=1 ";
    if (ab.productOneType) {//产品大类类型
      params["productOneType"] = "%/"+ab.productOneType+"/%";
      sql = sql + " and consult_type like :productOneType ";
      dataCount = dataCount + " and consult_type like :productOneType ";
    }
    if (ab.consultType) {//产品二类
      params["consult_type"] = ab.consultType;
      sql = sql + " and consult_type = :consult_type ";
      dataCount = dataCount + " and consult_type = :consult_type ";
    }
    if (ab.status) {//需求状态
      params["status"] = ab.status;
      sql = sql + " and status=:status ";
      dataCount = dataCount + " and status=:status ";
    }
    if (ab.contactsName) {//联系人
      params["contacts_name"] = "%"+ab.contactsName+"%";
      sql = sql + " and contacts_name like :contacts_name ";
      dataCount = dataCount + " and contacts_name like :contacts_name ";
    }
    if (ab.contactsMobile) {//联系电话
      params["contacts_moblie"] = "%"+ab.contactsMobile+"%";
      sql = sql + " and contacts_moblie like :contacts_moblie ";
      dataCount = dataCount + " and contacts_moblie like :contacts_moblie ";
    }
    if (ab.needNum) {//需求号
      params["need_num"] = "%"+ab.needNum+"%";
      sql = sql + " and need_num like :need_num ";
      dataCount = dataCount + " and need_num like :need_num ";
    }
    if (ab.servicerName) {//服务商
      params["servicer_name"] = "%"+ab.servicerName+"%";
      sql = sql + " and servicer_name like :servicer_name ";
      dataCount = dataCount + " and servicer_name like :servicer_name ";
    }
    if (ab.clerkName) {//业务员
      params["clerkName"] = "%"+ab.clerkName+"%";
      sql = sql + " and solution_content->'$.clerkName' like :clerkName ";
      dataCount = dataCount + " and solution_content->'$.clerkName' like :clerkName ";
    }
    if (ab.clerkPhone) {//业务员电话
      params["clerkPhone"] = "%"+ab.clerkPhone+"%";
      sql = sql + " and solution_content->'$.clerkPhone' like :clerkPhone ";
      dataCount = dataCount + " and solution_content->'$.clerkPhone' like :clerkPhone ";
    }
    //修改时间
    if (ab.dateList && ab.dateList.length==2 ) {
      params["startDate"] = ab.dateList[0];
      params["endDate"] = ab.dateList[1];
      if(ab.dateList[0]){
        sql = sql + " and updated_at >= :startDate ";
        dataCount = dataCount + " and updated_at >= :startDate ";
      }
      if(ab.dateList[1]){
        sql = sql + " and updated_at <= :endDate ";
        dataCount = dataCount +  " and updated_at <= :endDate ";
      }
    }
    sql = sql + " order by updated_at " + sortType + " limit :limit offset :offset";
    var list = await this.customQuery(sql, params);
    returnRes.rows = list;
    // var result = system.getResultSuccess(list);
    var tmpResultCount = await this.customQuery(dataCount, params);
    // result.dataCount = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    returnRes.total = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    var result = system.getResultSuccess(returnRes);
    return result;

  }
  /**
   * 申请主体列表查询
   * @param {*} ab 过滤条件参数
   */
  async getApplicantList(ab) {
    var pageSize = ab.pageSize ? Number(ab.pageSize) : 10;
    var currentPage = ab.currentPage ? Number(ab.currentPage) : 1;
    var offset = (currentPage - 1) * pageSize;
    var params = {
      limit: pageSize,
      offset: offset
    };
    var returnRes = {
      pageSize: pageSize,//每页条数
      curPage: currentPage,//当前页数
      search: ab,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var dataCount = "select count(1) as dataCount from (SELECT count( apply_name ) AS count,apply_name FROM b_apply_info  WHERE deleted_at IS NULL ";
    var sql = "SELECT count( apply_name ) AS count,servicer_code,servicer_name, user_id," +
      "user_name, apply_name, credit_code, apply_type, operator, regist_capital," +
      "business_term, establish_time, business_term, domicile," +
      "ent_type, business_scope,created_at " +
      "FROM b_apply_info  WHERE deleted_at IS NULL ";
    if (ab.applyType) {
      params["apply_type"] = ab.applyType;
      sql = sql + " and apply_type=:apply_type ";
      dataCount = dataCount + " and apply_type=:apply_type ";
    }
    if (ab.applyName) {
      params["apply_name"] = "%"+ab.applyName+"%";
      sql = sql + " and apply_name like :apply_name ";
      dataCount = dataCount + " and apply_name like :apply_name ";
    }
    if (ab.creditCode) {
      params["credit_code"] = "%"+ab.creditCode+"%";
      sql = sql + " and credit_code like :credit_code ";
      dataCount = dataCount + " and credit_code like :credit_code ";
    }
    if (ab.domicile) {
      params["domicile"] = "%"+ab.domicile+"%";
      sql = sql + " and domicile like :domicile ";
      dataCount = dataCount + " and domicile like :domicile ";
    }
    dataCount = dataCount + " GROUP BY apply_name ) as applyinfo ";
    sql = sql + " GROUP BY apply_name  ORDER BY id DESC LIMIT :limit OFFSET :offset";

    var list = await this.customQuery(sql, params);
    var tmpResultCount = await this.customQuery(dataCount, params);
    returnRes.total = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    returnRes.rows = list;
    var result = system.getResultSuccess(returnRes);
    return result;
  }
  /**
   * 根据社会统一信用代码获取申请主体信息
   */
  async getApplyInfoByCreditCode(creditCode) {
    var params = {
      credit_code: creditCode
    };
    var sql = "select * from b_apply_info where deleted_at is null and credit_code=:credit_code order by id desc limit 1 ";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   * 根据主体名称获取业务信息
   */
  async getProductBusinessInfoByApplicant(credit_code) {
    var params = {
      credit_code: credit_code,
      credit_code2:credit_code
    };
    var sql = "select * from v_order_oproduct_odelivery where "+
    "(deliver_content->'$.companyInfo' is not null and deliver_content->'$.companyInfo.creditCode'=:credit_code) "+
    // " or "+
    // " (deliver_content -> '$.proposerInfo' IS NOT NULL "+
    // "AND deliver_content -> '$.proposerInfo.businessLicense' IS NOT NULL "+
    // "AND deliver_content -> '$.proposerInfo.businessLicense.enterpriseCode' = :credit_code2)"+
    " order by updated_at desc";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   * 获取服务商列表
   * @param {*} ab 
   */
  async getServiceProviderList(ab) {
    var pageSize = ab.pageSize ? Number(ab.pageSize) : 10;
    var currentPage = ab.currentPage ? Number(ab.currentPage) : 1;
    var offset = (currentPage - 1) * pageSize;
    var params = {
      limit: pageSize,
      offset: offset
    };
    var sortType = "desc";
    if (ab.sortType && ab.sortType == "asc") {
      sortType = "asc";
    }
    var returnRes = {
      pageSize: pageSize,//每页条数
      curPage: currentPage,//当前页数
      search: ab,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var dataCount = "select count(1) as dataCount  FROM x_service_info  WHERE deleted_at IS NULL  ";
    var sql = "SELECT servicer_code, servicer_name, servicer_short_name,province_name, city_name, region_name, is_enabled, principal_name," +
      "principal_mobile, created_at  FROM x_service_info  WHERE deleted_at IS NULL ";
    if (ab.isEnabled===0 || ab.isEnabled===1) {
      params["is_enabled"] = ab.isEnabled;
      sql = sql + " and is_enabled=:is_enabled ";
      dataCount = dataCount + " and is_enabled=:is_enabled ";
    }
    if (ab.regionName) {
      params["region_name"] = ab.regionName;
      sql = sql + " and region_name=:region_name ";
      dataCount = dataCount + " and region_name=:region_name ";
    }
    if (ab.servicerCode) {
      params["servicer_code"] = "%"+ab.servicerCode+"%";
      sql = sql + " and servicer_code like :servicer_code ";
      dataCount = dataCount + " and servicer_code like :servicer_code ";
    }
    if (ab.servicerShortName) {
      params["servicer_short_name"] = "%"+ab.servicerShortName+"%";
      sql = sql + " and servicer_short_name like :servicer_short_name ";
      dataCount = dataCount + " and servicer_short_name like :servicer_short_name ";
    }
    sql = sql + " ORDER BY created_at " + sortType + " LIMIT :limit OFFSET :offset";

    var list = await this.customQuery(sql, params);
    var tmpResultCount = await this.customQuery(dataCount, params);
    returnRes.total = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    returnRes.rows = list;
    var result = system.getResultSuccess(returnRes);
    return result;
  }

  /**
   * 获取产品二类列表
   */
  async getProductTypeTwoList() {
    var sql = "SELECT id,type_code,type_name FROM `x_product_type` where p_id is not null and deleted_at is null and is_enabled=1 ORDER BY id asc";
    var list = await this.customQuery(sql, {});
    return list;
  }
  /**
   * 获取产品二类列表
   */
  async getProductListByType(typeId, servicerCode) {
    var params = {
      typeId: typeId,
      servicerCode: servicerCode || ""
    };
    var sql = "SELECT servicer_code <=> :servicerCode AS isSelected, id," +
      "region_name,is_allocation,servicer_name,servicer_code FROM `x_product` WHERE " +
      "deleted_at IS NULL  AND is_enabled = 1 AND product_type_id = :typeId order by id asc";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   * 获取服务商分配产品列表（id列表）
   * @param {*} servicerCode 
   */
  async getAssignedProductsByServicerCode(servicerCode){
    var params = {
      servicerCode: servicerCode
    };
    var sql = "SELECT id FROM `x_product` WHERE " +
      "deleted_at IS NULL  AND is_enabled = 1 AND is_allocation=1 and servicer_code is not null and servicer_code = :servicerCode order by id asc";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   * 删除服务商产品配置
   * @param {*} servicerCode 服务商编码
   * @param {*} t 事务
   */
  async deleteAllProductByServicerCode(servicerCode, t) {
    var sql = "update x_product set is_allocation=0,servicer_name=null,servicer_code=null where servicer_code=:servicerCode ";
    var params = {
      servicerCode: servicerCode
    };
    await this.customUpdate(sql, params, t);
  }
  /**
   * 设置服务商产品信息
   * @param {*} idList 产品id列表
   * @param {*} servicerCode 服务商编码
   * @param {*} servicerName 服务商名称
   * @param {*} t 事务
   */
  async setProductByServicerCode(idList, servicerCode, servicerName, t) {
    for (var i = 0; i < idList.length; i++) {
      var sql = "update x_product set is_allocation=1,servicer_name=:servicerName,servicer_code=:servicerCode where id=:id and is_enabled=1 and is_allocation=0 and deleted_at is null ";
      var params = {
        id: idList[i], servicerCode: servicerCode, servicerName: servicerName
      };
      await this.customUpdate(sql, params, t);
    }
  }
  /**
   * Xboss系统 订单-列表查询
   */
  async getOrderQueryList(parambody) {
    var pageSize = parambody.pageSize ? Number(parambody.pageSize) : 10;
    var currentPage = parambody.currentPage ? Number(parambody.currentPage) : 1;
    var offset = (currentPage - 1) * pageSize;
    var params = {
      limit: pageSize,
      offset: offset
    };
    //更新时间排序，默认是降序
    var sortType = "desc";
    if (parambody.sortType == "asc") {
      sortType = "asc";
    }
    var returnRes = {
      pageSize: pageSize,//每页条数
      curPage: currentPage,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var countSql = "select count(1) as dataCount from v_order_oproduct_odelivery where deleted_at is null ";
    var sql = "select order_num,tx_orders_num,need_num,total_sum,user_name,user_id,updated_at,servicer_code,servicer_name,deliver_content, "+
    "product_type,product_type_name,order_snapshot,region_id,region_name,delivery_status,delivery_status_name "+
    " from v_order_oproduct_odelivery where deleted_at is null ";
    if (parambody.productOneType) {//产品大类类型
      params["productOneType"] = "%/"+parambody.productOneType+"/%";
      sql = sql + " and product_type like :productOneType ";
      countSql = countSql + " and product_type like :productOneType ";
    }
    //订单编号
    if (parambody.orderNum) {
      params["order_num"] = "%"+parambody.orderNum+"%";
      sql = sql + " and order_num like :order_num";
      countSql = countSql + " and order_num like :order_num";
    }
    //客户姓名 订单快照json
    if (parambody.contactsName) {
      params["contactsName"] = "%"+parambody.contactsName+"%";
      sql = sql + " and order_snapshot->'$.contactsName' like :contactsName ";
      countSql = countSql + " and order_snapshot->'$.contactsName' like :contactsName ";
    }
    //客户电话  订单快照json
    if (parambody.contactsPhone) {
      params["contactsPhone"] = "%"+parambody.contactsPhone+"%";
      sql = sql + " and order_snapshot->'$.contactsPhone' like :contactsPhone ";
      countSql = countSql + " and order_snapshot->'$.contactsPhone' like :contactsPhone ";
    }
    //服务顾问 交付内容json
    if (parambody.clerkName) {
      params["clerkName"] = "%"+parambody.clerkName +"%";
      sql = sql + " and deliver_content->'$.clerkName' like :clerkName ";
      countSql = countSql + " and deliver_content->'$.clerkName' like :clerkName ";
    }
    //顾问电话 交付内容json
    if (parambody.clerkPhone) {
      params["clerkPhone"] = "%"+parambody.clerkPhone+"%";
      sql = sql + " and deliver_content->'$.clerkPhone' like :clerkPhone ";
      countSql = countSql + " and deliver_content->'$.clerkPhone' like :clerkPhone ";
    }
    //服务商  编码servicer_code  名字servicer_name
    if (parambody.serviceCode) {
      params["serviceCode"] = "%"+parambody.serviceCode+"%";
      sql = sql + " and servicer_code like :serviceCode ";
      countSql = countSql + " and servicer_code like :serviceCode ";
    }
    //交付产品  产品类型名称（产品二类名称）product_type   product_type_name
    if (parambody.productType) {
      params["product_type"] = "%"+parambody.productType+"%";
      sql = sql + " and product_type like :product_type ";
      countSql = countSql + " and product_type  like :product_type ";
    }
    //交付状态  delivery_status  delivery_status_name
    if (parambody.deliveryStatus) {
      params["delivery_status"] = parambody.deliveryStatus;
      sql = sql + " and delivery_status = :delivery_status ";
      countSql = countSql + " and delivery_status = :delivery_status ";
    }
    //分页及排序组装sql
    sql = sql + " order by updated_at " + sortType + " limit :limit offset :offset";
    var list = await this.customQuery(sql, params);
    // var result = system.getResultSuccess(list);
    var tmpResultCount = await this.customQuery(countSql, params);
    returnRes.rows = list;
    returnRes.total = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    var result = system.getResultSuccess(returnRes);
    // result.dataCount = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    return result;
  }

  /**
   * Xboss系统 资质服务列表
   */
  async getQcOrderList(parambody) {
    var pageSize = parambody.pageSize ? Number(parambody.pageSize) : 10;
    var currentPage = parambody.currentPage ? Number(parambody.currentPage) : 1;
    var offset = (currentPage - 1) * pageSize;
    var params = {
      limit: pageSize,
      offset: offset
    };
    //更新时间排序，默认是降序
    var sortType = "desc";
    if (parambody.sortType == "asc") {
      sortType = "asc";
    }
    var returnRes = {
      pageSize: pageSize,//每页条数
      curPage: currentPage,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var countSql = "select count(1) as dataCount from v_order_oproduct_odelivery where deleted_at is null and (product_type = '/qcfw/icp/' or product_type = '/qcfw/edi/' ) ";
    var sql = "select order_num,tx_orders_num,need_num,user_name,user_id,updated_at,servicer_code,servicer_name,"+
    "product_type,product_type_name,order_snapshot,region_id,region_name,delivery_status,delivery_status_name "+
    " from v_order_oproduct_odelivery where deleted_at is null and (product_type = '/qcfw/icp/' or product_type = '/qcfw/edi/' ) ";
    //订单编号
    if (parambody.orderNum) {
      params["order_num"] = "%"+parambody.orderNum+"%";
      sql = sql + " and order_num like :order_num";
      countSql = countSql + " and order_num like :order_num";
    }
    //交付产品  产品类型名称（产品二类名称）product_type   product_type_name
    if (parambody.productType) {
      params["product_type"] = "%"+parambody.productType+"%";
      sql = sql + " and product_type like :product_type ";
      countSql = countSql + " and product_type  like :product_type ";
    }
    //客户姓名 订单快照json
    if (parambody.contactsName) {
      params["contactsName"] = "%"+parambody.contactsName+"%";
      sql = sql + " and order_snapshot->'$.contactsName' like :contactsName ";
      countSql = countSql + " and order_snapshot->'$.contactsName' like :contactsName ";
    }
    //客户电话  订单快照json
    if (parambody.contactsPhone) {
      params["contactsPhone"] = "%"+parambody.contactsPhone+"%";
      sql = sql + " and order_snapshot->'$.contactsPhone' like :contactsPhone ";
      countSql = countSql + " and order_snapshot->'$.contactsPhone' like :contactsPhone ";
    }
    //服务顾问 交付内容json
    if (parambody.clerkName) {
      params["clerkName"] = "%"+parambody.clerkName +"%";
      sql = sql + " and deliver_content->'$.clerkName' like :clerkName ";
      countSql = countSql + " and deliver_content->'$.clerkName' like :clerkName ";
    }
    //顾问电话 交付内容json
    if (parambody.clerkPhone) {
      params["clerkPhone"] = "%"+parambody.clerkPhone+"%";
      sql = sql + " and deliver_content->'$.clerkPhone' like :clerkPhone ";
      countSql = countSql + " and deliver_content->'$.clerkPhone' like :clerkPhone ";
    }
    //服务商  编码servicer_code  名字servicer_name
    if (parambody.serviceCode) {
      params["serviceCode"] = "%"+parambody.serviceCode+"%";
      sql = sql + " and servicer_code like :serviceCode ";
      countSql = countSql + " and servicer_code like :serviceCode ";
    }
    //交付状态  delivery_status  delivery_status_name
    if (parambody.deliveryStatus) {
      params["delivery_status"] = parambody.deliveryStatus;
      sql = sql + " and delivery_status = :delivery_status ";
      countSql = countSql + " and delivery_status = :delivery_status ";
    }
    //修改时间
    if (parambody.dateList && parambody.dateList.length==2 ) {
      params["startDate"] = parambody.dateList[0];
      params["endDate"] = parambody.dateList[1];
      if(parambody.dateList[0]){
        sql = sql + " and updated_at >= :startDate ";
        countSql = countSql + " and updated_at >= :startDate ";
      }
      if(parambody.dateList[1]){
        sql = sql + " and updated_at <= :endDate ";
        countSql = countSql +  " and updated_at <= :endDate ";
      }
    }
    //分页及排序组装sql
    sql = sql + " order by updated_at " + sortType + " limit :limit offset :offset";
    var list = await this.customQuery(sql, params);
    // var result = system.getResultSuccess(list);
    var tmpResultCount = await this.customQuery(countSql, params);
    returnRes.rows = list;
    returnRes.total = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    var result = system.getResultSuccess(returnRes);
    // result.dataCount = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    return result;
  }
  /**
   * Xboss系统 资质年报服务列表
   */
  async getQcAnnalsOrderList(parambody) {
    var pageSize = parambody.pageSize ? Number(parambody.pageSize) : 10;
    var currentPage = parambody.currentPage ? Number(parambody.currentPage) : 1;
    var offset = (currentPage - 1) * pageSize;
    var params = {
      limit: pageSize,
      offset: offset
    };
    //更新时间排序，默认是降序
    var sortType = "desc";
    if (parambody.sortType == "asc") {
      sortType = "asc";
    }
    var returnRes = {
      pageSize: pageSize,//每页条数
      curPage: currentPage,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var countSql = "select count(1) as dataCount from v_order_oproduct_odelivery where deleted_at is null and (product_type = '/qcfw/icpannals/' or product_type = '/qcfw/ediannals/' ) ";
    var sql = "select order_num,tx_orders_num,need_num,user_name,user_id,updated_at,servicer_code,servicer_name,"+
    "product_type,product_type_name,order_snapshot,region_id,region_name,delivery_status,delivery_status_name "+
    " from v_order_oproduct_odelivery where deleted_at is null and (product_type = '/qcfw/icpannals/' or product_type = '/qcfw/ediannals/' ) ";
    //订单编号
    if (parambody.orderNum) {
      params["order_num"] = "%"+parambody.orderNum+"%";
      sql = sql + " and order_num like :order_num";
      countSql = countSql + " and order_num like :order_num";
    }
    //交付产品  产品类型名称（产品二类名称）product_type   product_type_name
    if (parambody.productType) {
      params["product_type"] = "%"+parambody.productType+"%";
      sql = sql + " and product_type like :product_type ";
      countSql = countSql + " and product_type  like :product_type ";
    }
    //客户姓名 订单快照json
    if (parambody.contactsName) {
      params["contactsName"] = "%"+parambody.contactsName+"%";
      sql = sql + " and order_snapshot->'$.contactsName' like :contactsName ";
      countSql = countSql + " and order_snapshot->'$.contactsName' like :contactsName ";
    }
    //客户电话  订单快照json
    if (parambody.contactsPhone) {
      params["contactsPhone"] = "%"+parambody.contactsPhone+"%";
      sql = sql + " and order_snapshot->'$.contactsPhone' like :contactsPhone ";
      countSql = countSql + " and order_snapshot->'$.contactsPhone' like :contactsPhone ";
    }
    //服务顾问 交付内容json
    if (parambody.clerkName) {
      params["clerkName"] = "%"+parambody.clerkName +"%";
      sql = sql + " and deliver_content->'$.clerkName' like :clerkName ";
      countSql = countSql + " and deliver_content->'$.clerkName' like :clerkName ";
    }
    //顾问电话 交付内容json
    if (parambody.clerkPhone) {
      params["clerkPhone"] = "%"+parambody.clerkPhone+"%";
      sql = sql + " and deliver_content->'$.clerkPhone' like :clerkPhone ";
      countSql = countSql + " and deliver_content->'$.clerkPhone' like :clerkPhone ";
    }
    //服务商  编码servicer_code  名字servicer_name
    if (parambody.serviceCode) {
      params["serviceCode"] = "%"+parambody.serviceCode+"%";
      sql = sql + " and servicer_code like :serviceCode ";
      countSql = countSql + " and servicer_code like :serviceCode ";
    }
    //交付状态  delivery_status  delivery_status_name
    if (parambody.deliveryStatus) {
      params["delivery_status"] = parambody.deliveryStatus;
      sql = sql + " and delivery_status = :delivery_status ";
      countSql = countSql + " and delivery_status = :delivery_status ";
    }
    //修改时间
    if (parambody.dateList && parambody.dateList.length==2 ) {
      params["startDate"] = parambody.dateList[0];
      params["endDate"] = parambody.dateList[1];
      if(parambody.dateList[0]){
        sql = sql + " and updated_at >= :startDate ";
        countSql = countSql + " and updated_at >= :startDate ";
      }
      if(parambody.dateList[1]){
        sql = sql + " and updated_at <= :endDate ";
        countSql = countSql +  " and updated_at <= :endDate ";
      }
    }
    //分页及排序组装sql
    sql = sql + " order by updated_at " + sortType + " limit :limit offset :offset";
    var list = await this.customQuery(sql, params);
    // var result = system.getResultSuccess(list);
    var tmpResultCount = await this.customQuery(countSql, params);
    returnRes.rows = list;
    returnRes.total = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    var result = system.getResultSuccess(returnRes);
    // result.dataCount = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    return result;
  }

  /**
   *  Xboss系统 订单-详情查询
   */
  async getOrderDetailByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select * from v_order_oproduct_odelivery where order_num = :order_num";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   * 根据腾讯订单号（主订单号）及产品类型获取子订单列表
   * @param {*} tx_orders_num 腾讯订单号
   * @param {*} product_Type 产品类型（二类code）
   */
  async getQcInfoByTxOrderNumAndProductType(tx_orders_num,product_type){
    var params = {
      productType: product_type,
      txOrdersNum:tx_orders_num
    };
    var sql = "select order_snapshot,deliver_content from v_order_oproduct_odelivery where tx_orders_num = :txOrdersNum and product_type = :productType order by updated_at desc limit 1 ";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   * 获取资质证照年报列表
   * @param {*} orderNum 
   */
  async getAnnualReportByOrderNum(orderNum){
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,  '$.annualReport' ) as annualReportList from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.annualReport' is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   *  Xboss系统 订单-详情查询--出资比例列表
   */
  async getContributionInfoByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,  '$.contributionInfo.contributionData' ) as contributionInfoList from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.contributionInfo' is not null and deliver_content->'$.contributionInfo.contributionData' is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   * 订单详情-任职信息列表
   */
  async getPositionInfoByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,  '$.positionInfo.positionData' ) as positionInfoList from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.positionInfo' is not null and deliver_content->'$.positionInfo.positionData' is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   *  Xboss系统 订单-详情查询--资质证照-公司人员情况
   */
  async getPrincipalInfoByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,  '$.proposerInfo.principalInfo' ) as principalInfo from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.proposerInfo' is not null and deliver_content->'$.proposerInfo.principalInfo' is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   *  Xboss系统 订单-详情查询--资质证照-股权结构
   */
  async getShareholderDataByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,  '$.shareholderData' ) as shareholderData from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.shareholderData' is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   *  Xboss系统 订单-详情查询--资质证照-网站或APP信息
   */
  async getWebAppByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,  '$.implementationPlanInfo.webApp' ) as webApp from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.implementationPlanInfo' is not null and deliver_content->'$.implementationPlanInfo.webApp' is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }
   /**
   *  Xboss系统 订单-详情查询--资质证照-拟开展服务项目
   */
  async getServiceProjectByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,  '$.implementationPlanInfo.serviceProjectEdi' ) as serviceProjectEdi, "+
    "json_extract(deliver_content,  '$.implementationPlanInfo.serviceProjectIcp' ) as serviceProjectIcp,product_type"+
    " from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.implementationPlanInfo' "+
    " is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }

  /**
   *  Xboss系统 订单-详情查询--资质证照-材料清单(固定上传项)
   */
  async getMaterialsInfoByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,'$.otherMaterialsInfo' ) as materialsInfo "+
    "from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.otherMaterialsInfo' is not null"+
    " limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   *  Xboss系统 订单-详情查询--企业服务-材料清单(固定上传项)
   */
  async getIcMaterialsInfoByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,'$.regInfo.uploadList' ) as materialsInfo "+
    "from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.regInfo' is not null"+
    " and deliver_content->'$.regInfo.uploadList' is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }

  /**
   *  Xboss系统 订单-详情查询--资质证照-专项审批项目 ICP
   */
  async getSpecialApprovalInfoByOrderNum(orderNum) {
    var params = {
      order_num: orderNum
    };
    var sql = "select json_extract(deliver_content,  '$.implementationPlanInfo.specialApproval' ) as specialApprovalList "+
    " from v_order_oproduct_odelivery where order_num = :order_num and deliver_content->'$.implementationPlanInfo' "+
    " is not null limit 1";
    var list = await this.customQuery(sql, params);
    return list;
  }
  /**
   * Xboss系统 交易流水列表查询
   */
  async getOrderTransactionPipelineList(parambody) {
    var pageSize = parambody.pageSize ? Number(parambody.pageSize) : 10;
    var currentPage = parambody.currentPage ? Number(parambody.currentPage) : 1;
    var offset = (currentPage - 1) * pageSize;
    var params = {
      limit: pageSize,
      offset: offset
    };
    //更新时间排序，默认是降序
    var sortType = "desc";
    if (parambody.sortType == "asc") {
      sortType = "asc";
    }
    var returnRes = {
      pageSize: pageSize,//每页条数
      curPage: currentPage,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var countSql = "select count(1) as dataCount from v_order_oproduct_odelivery where deleted_at is null ";
    var sql = "select * from v_order_oproduct_odelivery where deleted_at is null ";
    if (parambody.productOneType) {//产品大类类型
      params["productOneType"] = "%/"+parambody.productOneType+"/%";
      sql = sql + " and product_type like :productOneType ";
      countSql = countSql + " and product_type like :productOneType ";
    }
    //时间段查询--开始日期
    if (parambody.startDate) {
      params["startDate"] = parambody.startDate;
      sql = sql + " and updated_at >= :startDate ";
      countSql = countSql + " and updated_at  >= :startDate  ";
    }
    //时间段查询--结束日期
    if (parambody.endDate) {
      params["endDate"] = parambody.endDate;
      sql = sql + " and updated_at <=:endDate ";
      countSql = countSql + " and updated_at  <=:endDate ";
    }

    //订单编号
    if (parambody.orderNum) {
      params["order_num"] = "%"+parambody.orderNum+"%";
      sql = sql + " and order_num like :order_num ";
      countSql = countSql + " and order_num like :order_num ";
    }
    //服务商  编码servicer_code  名字servicer_name
    if (parambody.servicerCode) {
      params["servicer_code"] = "%"+parambody.servicerCode+"%";
      sql = sql + " and servicer_code like :servicer_code ";
      countSql = countSql + " and servicer_code like :servicer_code ";
    }
    //交付产品  产品类型名称（产品二类名称）product_type   product_type_name
    if (parambody.productType) {
      params["product_type"] = "%"+parambody.productType+"%";
      sql = sql + " and product_type like :product_type ";
      countSql = countSql + " and product_type like :product_type ";
    }
    //分页及排序组装sql
    sql = sql + " order by updated_at " + sortType + " limit :limit offset :offset";
    var list = await this.customQuery(sql, params);
    var tmpResultCount = await this.customQuery(countSql, params);
    returnRes.total = tmpResultCount && tmpResultCount.length > 0 ? tmpResultCount[0].dataCount : 0;
    returnRes.rows = list;
    var result = system.getResultSuccess(returnRes);
    return result;
  }
  /**
   * 根据主订单号(腾讯订单号)获取关联产品
   * @param {*} mainOrderNum 
   * @param {*} exclvarudeOrderNum 
   */
  async getRelatedProductsList(mainOrderNum,excludeOrderNum){
    var params = {
      mainOrderNum: mainOrderNum,
      excludeOrderNum:excludeOrderNum
    };
    var sql = "select product_type,product_type_name,order_num from v_order_oproduct_odelivery where product_type_name is not null and tx_orders_num= :mainOrderNum and order_num !=:excludeOrderNum ";
    var list = await this.customQuery(sql, params);
    return list;
  }
}
module.exports = ServiceInfoDao;