const system = require("../../../system");
const {PDICT} = require("../../../../config/platform");
const ServiceBase = require("../../sve.base");
var settings = require("../../../../config/settings");
class ServiceInfoService extends ServiceBase {
  constructor() {
    super("serviceprovider", ServiceBase.getDaoName(ServiceInfoService));
  }
  /**
   * 校验组装参数
   * @param {*} ab 
   */
  async verifyAndPackageCreateParams(ab){
    var params = {};
    if(!ab.isEnabled || ab.isEnabled!=1){
      params["is_enabled"] = 0;
    }else{
      params["is_enabled"] = 1;
    }
    if(!ab.servicerCode){//新增
      if(!ab.pushDomainAddr){
        return system.getResultFail(-101,"登录域名不能为空");
      }
      params["push_domain_addr"]=ab.pushDomainAddr;
  
      if(!ab.applyType){
        return system.getResultFail(-102,"账号类型不能为空");
      }
      params["apply_type"]=ab.applyType;
  
      if(!ab.servicerShortName){
        return system.getResultFail(-103,"服务商简称不能为空");
      }
      params["servicer_short_name"]=ab.servicerShortName;
  
      if(!ab.servicerName){
        return system.getResultFail(-104,"企业名称不能为空");
      }
      params["servicer_name"]=ab.servicerName;
    }
    if(!ab.bankAccount){
      return system.getResultFail(-105,"公司银行开户名不能为空");
    }
    params["bank_account"]=ab.bankAccount;
    
    if(!ab.bankAccountNum){
      return system.getResultFail(-106,"公司银行账号不能为空");
    }
    params["bank_account_num"]=ab.bankAccountNum;

    if(!ab.subBankAccount){
      return system.getResultFail(-107,"开户行支行名称不能为空");
    }
    params["sub_bank_account"]=ab.subBankAccount;

    if(!ab.subBankAccountNum){
      return system.getResultFail(-108,"开户行支行联行号不能为空");
    }
    params["sub_bank_account_num"]=ab.subBankAccountNum;

    if(!ab.settlementCycle){
      return system.getResultFail(-109,"结算周期不能为空");
    }
    params["settlement_cycle"]=ab.settlementCycle;

    if(!ab.regionName){
      return system.getResultFail(-110,"所在地区不能为空");
    }
    params["region_name"]=ab.regionName;

    if(!ab.servicerAddress){
      return system.getResultFail(-111,"详细地址不能为空");
    }
    params["servicer_address"]=ab.servicerAddress;

    if(!ab.principalName){
      return system.getResultFail(-112,"负责人不能为空");
    }
    params["principal_name"]=ab.principalName;

    if(!ab.principalMobile){
      return system.getResultFail(-113,"联系电话不能为空");
    }
    params["principal_mobile"]=ab.principalMobile;
    return system.getResultSuccess(params);
  }

  /**
   * 新增/修改服务商
   */
  async createServiceProvider(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var ab = pobj.actionBody;
    var params={};
    var pakageRes = await this.verifyAndPackageCreateParams(ab);//校验组装参数
    if(pakageRes.retcode!=0){
      return pakageRes;
    }else{
      params = pakageRes.data;
    }
    var servicer_code = "";
    if(ab.servicerCode){//传入服务商code 为修改服务商信息
      servicer_code = ab.servicerCode;
      params["servicer_code"] = servicer_code;
      var serviceinfo = await this.dao.model.findOne({
        where:{servicer_code:servicer_code},
        raw:true
      });
      if(!serviceinfo || !serviceinfo.id){
        return system.getResultFail(-300,"未知服务商");
      }
      params["id"] = serviceinfo.id;
      var self = this;
      return this.db.transaction(async function (t) {
        await self.dao.update(params,t);//修改服务商信息
        await self.editServiceProduct(ab.productList,serviceinfo.servicer_code,serviceinfo.servicer_name,params["is_enabled"],t);//修改服务商产品信息
        return system.getResultSuccess(); 
      })
      
    }else{//新增服务商信息
      servicer_code = await this.getBusUid("S_");
      params["servicer_code"] = servicer_code;
      var self = this;
      return this.db.transaction(async function (t) {
        var serviceinfo = await self.dao.create(params,t);//修改服务商信息
        await self.editServiceProduct(ab.productList,serviceinfo.servicer_code,serviceinfo.servicer_name,params["is_enabled"],t);//编辑服务商产品信息
        return system.getResultSuccess(serviceinfo); 
      })
    }
  }
  /**
   * 编辑服务商产品
   * @param {*} productList 产品id列表
   * @param {*} servicerCode 服务商编码
   * @param {*} isEnabled 服务商是否启用
   * @param {*} t 事务
   */
  async editServiceProduct(productList,servicerCode,servicerName,isEnabled,t){
    await this.dao.deleteAllProductByServicerCode(servicerCode,t);//根据服务商编码删除该服务商所有产品
    // if(isEnabled==1){//服务商已启用
      if(productList && productList.length>0){
        await this.dao.setProductByServicerCode(productList,servicerCode,servicerName,t);//给服务商设置产品
      }
      
    // }
  }
  /**
   * 服务商详情
   */
  async getServiceInfoDetail(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var ab = pobj.actionBody;
    if(!ab.servicerCode){
      return system.getResultFail(-101,"服务商编码不能为空");
    }
    var serviceinfo = await this.dao.model.findOne({
      where:{servicer_code:ab.servicerCode},
      raw:true
    });
    if(!serviceinfo || !serviceinfo.id){
      return system.getResultFail(-300,"未知服务商信息");
    }
    //获取服务商分配产品列表
    var productList = await this.dao.getAssignedProductsByServicerCode(ab.servicerCode);
    var plist = [];
    if(productList && productList.length>0){
      for(var i=0;i<productList.length;i++){
        var id = productList[i].id;
        if(id){
          plist.push(id);
        }
      }
    }
    serviceinfo["productList"] = plist;
    return system.getResultSuccess(serviceinfo);
  }
  /**
   * 服务商列表
   */
  async getServiceInfoList(pobj){
    var ab = {};
    if(pobj && pobj.actionBody){
      ab = pobj.actionBody
    }
    var result = await this.dao.getServiceProviderList(ab);
    return result;
  }

  /**
   * 服务商列表(筛选条件)
   */
  async getServiceProviderList(pobj){
    var ab = {};
    if(pobj && pobj.actionBody){
      ab = pobj.actionBody
    }
    var list = await this.dao.model.findAll({
      attributes:["servicer_code","servicer_name","apply_type"],
      raw:true,
    })
    return system.getResultSuccess(list);
  }
}
module.exports = ServiceInfoService;