var system = require("../../../system");
var settings = require("../../../../config/settings");
const AppServiceBase = require("../../app.base");
//XBoss系统通用接口
class UtilsXbossService extends AppServiceBase {
  constructor() {
    super();
    this.serviceInfoDao = system.getObject("db.serviceprovider.serviceInfoDao")
  }
  /**
   * xboss系统 需求详情
   */
  async xneedDetail(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var ab = pobj.actionBody;
    if(!ab.servicerCode){
      return system.getResultFail(-101,"服务商编码不能为空");
    }
    if(!ab.needNum){
      return system.getResultFail(-102,"需求编码不能为空");
    }
    var serviceInfo = await this.serviceInfoDao.model.findOne({
      where:{servicer_code:ab.servicerCode},
      attributes:[
        "id",
        "created_at",
        "servicer_code",
        "servicer_name",
        "servicer_short_name",
        "business_license",
        // "business_license_address",
        "credit_code",
        "legal_identity_card",
        "legal_name",
        "legal_mobile",
        "principal_name","principal_mobile",
        "legal_identity_card_no",
        "push_domain_addr"
      ],
      raw:true
    });
    if(!serviceInfo || !serviceInfo.id){
      return system.getResultFail(-300,"未知服务商");
    }
    var resData = {serviceInfo:serviceInfo};
    var list = await this.serviceInfoDao.getNeedAndSolutionInfoByNeedNum(ab.needNum);
    if(list && list.length>0){
      resData["needSolution"] = list[0];
    }
    return system.getResultSuccess(resData);
  }
  /**
   * xboss系统 需求列表
   */
  async xneedList(pobj){
    var ab = {};
    if(pobj && pobj.actionBody){
      ab = pobj.actionBody
    }
    var result = await this.serviceInfoDao.getNeedSolutionList(ab);
    return result;
  }

  /**
   * xboss系统 申请主体列表
   */
  async xApplicantList(pobj){
    var ab = {};
    if(pobj && pobj.actionBody){
      ab = pobj.actionBody
    }
    var result = await this.serviceInfoDao.getApplicantList(ab);
    return result;
  }
    /**
   * xboss系统 申请主体详情
   */
  async xApplicantDetail(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var ab = pobj.actionBody;
    if(!ab.creditCode){
      return system.getResultFail(-101,"社会统一信用代码不能为空");
    }
    var applyInfoRes = await this.serviceInfoDao.getApplyInfoByCreditCode(ab.creditCode);
    if(!applyInfoRes || applyInfoRes.length<1){
      return system.getResultFail(-300,"未知申请主体");
    }
    var applyInfo = applyInfoRes[0];
    if(!applyInfo || !applyInfo.apply_name){
      return system.getResultFail(-301,"未知申请主体");
    }
    var resData = {applyInfo:applyInfo};
    var list = await this.serviceInfoDao.getProductBusinessInfoByApplicant(applyInfo.credit_code);
    resData["productBusinessInfo"] = list;
    return system.getResultSuccess(resData);
  }

  /**
   * 获取服务商产品列表
   * @param {*} pobj 
   */
  async getProductListBySrvicerCode(pobj){
    // if(!pobj || !pobj.actionBody){
    //   return system.getResultFail(-100,"参数错误");
    // }
    var ab = pobj.actionBody;
    // if(!ab.servicerCode){
    //   return system.getResultFail(-101,"服务商编码不能为空");
    // }
    var typelist = await this.serviceInfoDao.getProductTypeTwoList();//获取所有产品二类
    if(typelist && typelist.length>0){
      for(var i=0;i<typelist.length;i++){
        var productList = await this.serviceInfoDao.getProductListByType(typelist[i].id,ab.servicerCode);//根据产品类型获取产品列表
        typelist[i].productList = productList;
      }
    }
    return system.getResultSuccess({rows:typelist});
  }
  /**
   * Xboss系统 订单管理--查询--列表查询展示
   */
  async xOrderQueryList(pobj){
    var parambody = {};
    if(pobj && pobj.actionBody){
      parambody = pobj.actionBody;
    }
    var result = await this.serviceInfoDao.getOrderQueryList(parambody);
    return result;
  }
  /**
   * Xboss系统 资质服务列表
   */
  async getQcOrderList(pobj){
    var parambody = {};
    if(pobj && pobj.actionBody){
      parambody = pobj.actionBody;
    }
    var result = await this.serviceInfoDao.getQcOrderList(parambody);
    return result;
  }
  /**
   * Xboss系统 资质年报服务列表
   */
  async getQcAnnalsOrderList(pobj){
    var parambody = {};
    if(pobj && pobj.actionBody){
      parambody = pobj.actionBody;
    }
    var result = await this.serviceInfoDao.getQcAnnalsOrderList(parambody);
    return result;
  }

  /**
   *  Xboss系统 订单详情展示
   */
  async xOrderDetail(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNum){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var list = await this.serviceInfoDao.getOrderDetailByOrderNum(parambody.orderNum);
    if(list && list.length>0){
      var orderdetail = list[0] || {};
      var relatedProducts = [];//关联产品
      if(orderdetail && orderdetail.tx_orders_num && orderdetail.order_num){
        //获取关联产品列表
        var relatedProductsList = await this.serviceInfoDao.getRelatedProductsList(orderdetail.tx_orders_num,orderdetail.order_num);
        relatedProducts = relatedProductsList;
        //判断产品大类为资质证照
        if(orderdetail.product_type && orderdetail.product_type.indexOf("/qcfw/")>=0){
          if(orderdetail.servicer_code){
            //获取服务商信息
            var serviceInfo = await this.serviceInfoDao.model.findOne({
              where:{servicer_code:orderdetail.servicer_code},
              attributes:[
                "id",
                "created_at",
                "servicer_code",
                "servicer_name",
                "servicer_short_name",
                "business_license",
                "credit_code",
                "legal_identity_card",
                "legal_name",
                "legal_mobile",
                "principal_name",
                "principal_mobile",
                "legal_identity_card_no",
                "push_domain_addr"
              ],
              raw:true
            });
            orderdetail["serviceInfo"] = serviceInfo || null;
          }
          
          if(orderdetail.product_type=="/qcfw/icpannals/"){//icp年報
            //获取资质证照信息
            var qcList = await this.serviceInfoDao.getQcInfoByTxOrderNumAndProductType(orderdetail.tx_orders_num,"/qcfw/icp/");
            orderdetail["qcInfo"]=qcList&&qcList.length>0?qcList[0]:null;
          }
          if(orderdetail.product_type=="/qcfw/ediannals/"){//edi年報
            //获取资质证照信息
            var qcList = await this.serviceInfoDao.getQcInfoByTxOrderNumAndProductType(orderdetail.tx_orders_num,"/qcfw/edi/");
            orderdetail["qcInfo"]=qcList&&qcList.length>0?qcList[0]:null;
          }
        }
      }
      orderdetail["relatedProducts"]=relatedProducts;//关联产品
      return system.getResultSuccess(orderdetail);
    }else{
      return system.getResultFail(-102,"未查询到该订单号");
    }
  }
  //获取资质年报列表
  async getAnnualReportByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getAnnualReportByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var annualReportList = list[0].annualReportList;
      if(annualReportList && annualReportList.length>0){
        returnRes.rows = annualReportList;
        returnRes.total = returnRes.pageSize = annualReportList.length;
      }
    }
    return system.getResultSuccess(returnRes);
  }
  /**
   *  Xboss系统 订单详情出资比例
   */
  async getContributionInfoByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getContributionInfoByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var contributionInfoList = list[0].contributionInfoList;
      if(contributionInfoList && contributionInfoList.length>0){
        returnRes.rows = contributionInfoList;
        returnRes.total = returnRes.pageSize = contributionInfoList.length;
      }
    }
    return system.getResultSuccess(returnRes);
  }
  /**
   *  Xboss系统 订单-详情查询--资质证照-公司人员情况
   */
  async getPrincipalInfoByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getPrincipalInfoByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var principalInfo = list[0].principalInfo;
      if(principalInfo && principalInfo.length>0){
        returnRes.rows = principalInfo;
        returnRes.total = returnRes.pageSize = principalInfo.length;
      }
    }
    return system.getResultSuccess(returnRes);
  }
  /**
   *  Xboss系统 订单-详情查询--资质证照-股权结构
   */
  async getShareholderDataByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getShareholderDataByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var shareholderData = list[0].shareholderData;
      if(shareholderData && shareholderData.length>0){
        returnRes.rows = shareholderData;
        returnRes.total = returnRes.pageSize = shareholderData.length;
      }
    }
    return system.getResultSuccess(returnRes);
  }
  /**
   *  Xboss系统 订单-详情查询--资质证照-网站或APP信息
   */
  async getWebAppByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getWebAppByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var webApp = list[0].webApp;
      if(webApp && webApp.length>0){
        returnRes.rows = webApp;
        returnRes.total = returnRes.pageSize = webApp.length;
      }
    }
    return system.getResultSuccess(returnRes);
  }
  /**
   *  Xboss系统 订单-详情查询--资质证照-拟开展服务项目
   */
  async getServiceProjectByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getServiceProjectByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var product_type = list[0].product_type;
      if(product_type){
        if(product_type=="/qcfw/icp/"){
          var serviceProjectIcp = list[0].serviceProjectIcp;
          if(serviceProjectIcp && serviceProjectIcp.length>0){
            returnRes.rows = serviceProjectIcp;
            returnRes.total = returnRes.pageSize = serviceProjectIcp.length;
          }
        }
        if(product_type=="/qcfw/edi/"){
          var serviceProjectEdi = list[0].serviceProjectEdi;
          if(serviceProjectEdi && serviceProjectEdi.length>0){
            returnRes.rows = serviceProjectEdi;
            returnRes.total = returnRes.pageSize = serviceProjectEdi.length;
          }
        }
      }
      
    }
    return system.getResultSuccess(returnRes);
  }

   /**
   *  Xboss系统 订单-详情查询--资质证照-专项审批项目 ICP
   */
  async getSpecialApprovalInfoByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getSpecialApprovalInfoByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var specialApprovalList = list[0].specialApprovalList;
      if(specialApprovalList && specialApprovalList.length>0){
        returnRes.rows = specialApprovalList;
        returnRes.total = returnRes.pageSize = specialApprovalList.length;
      }
      
    }
    return system.getResultSuccess(returnRes);
  }
  /**
   *  Xboss系统 订单-详情查询--资质证照-材料清单(固定上传项)
   */
  async getMaterialsInfoByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getMaterialsInfoByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var materialsInfo = list[0].materialsInfo;
      if(materialsInfo && materialsInfo.length>0){
        returnRes.rows = materialsInfo;
        returnRes.total = returnRes.pageSize = materialsInfo.length;
      }
    }
    return system.getResultSuccess(returnRes);
  }
  /**
   *  Xboss系统 订单-详情查询--企业服务-材料清单
   */
  async getIcMaterialsInfoByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getIcMaterialsInfoByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var materialsInfo = list[0].materialsInfo;
      if(materialsInfo && materialsInfo.length>0){
        returnRes.rows = materialsInfo;
        returnRes.total = returnRes.pageSize = materialsInfo.length;
      }
    }
    return system.getResultSuccess(returnRes);
  }
  /**
   * Xboss系统 交易流水列表
   */
  async xOrderTransactionPipelineList(pobj){
    var parambody = {};
    if(pobj && pobj.actionBody){
      parambody = pobj.actionBody;
    }
    var result = await this.serviceInfoDao.getOrderTransactionPipelineList(parambody);
    return result;
  }

  /**
   * 订单详情-任职信息列表
   */
  async getPositionInfoByOrderNum(pobj){
    if(!pobj || !pobj.actionBody){
      return system.getResultFail(-100,"参数错误");
    }
    var parambody = pobj.actionBody;
    if(!parambody.orderNumber){
      return system.getResultFail(-101,"订单号不能为空");
    }
    var returnRes = {
      pageSize: 10,//每页条数
      curPage: 1,//当前页数
      search: parambody,
      orderArr: null,//排序字段
      total: 0,//总记录条数
      rows: []
    };
    var list = await this.serviceInfoDao.getPositionInfoByOrderNum(parambody.orderNumber);
    if(list && list.length>0){
      var positionInfoList = list[0].positionInfoList;
      if(positionInfoList && positionInfoList.length>0){
        returnRes.rows = positionInfoList;
        returnRes.total = returnRes.pageSize = positionInfoList.length;
      }
    }
    return system.getResultSuccess(returnRes);
  }
}
module.exports = UtilsXbossService;
